# -*- coding: utf-8 -*-
"""Specifications for callback functions passed in to an API"""
from .backcall import callback_prototype

__author__ = 'Thomas Kluyver'
__email__ = 'takowl@gmail.com'
__version__ = '0.2.0'
